@@ -22,7 +22,7 @@ use vars qw($VERSION $Tags);
 
 BEGIN
 {
-  $VERSION = "1.07";
+  $VERSION = "1.08";
 
   $Tags =
   {
@@ -158,10 +158,10 @@ BEGIN
   };
 }
 
-use Gedcom::Grammar    1.07;
-use Gedcom::Individual 1.07;
-use Gedcom::Family     1.07;
-use Gedcom::Event      1.07;
+use Gedcom::Grammar    1.08;
+use Gedcom::Individual 1.08;
+use Gedcom::Family     1.08;
+use Gedcom::Event      1.08;
 
 sub new
 {
@@ -246,6 +246,20 @@ sub write_xml
   my $self  = shift;
   my $file  = shift or die "No filename specified";
   $self->{fh} = FileHandle->new($file, "w") or die "Can't open $file: $!";
+  $self->{fh}->print(<<'EOH');
+<!--
+
+This output was generated by Gedcom.pm.
+Gedcom.pm is Copyright 1999-2000, Paul Johnson (pjcj@cpan.org)
+Version 1.08 - 8th May 2000
+
+Gedcom.pm is free.  It is licensed under the same terms as Perl itself.
+
+The latest version of Gedcom.pm should be available from my homepage:
+http://www.pjcj.fsnet.co.uk
+
+EOH
+  $self->{fh}->print("Generated on " . localtime() . "\n\n-->\n\n");
   $self->{record}->write_xml($self->{fh});
   $self->{fh}->close or die "Can't close $file: $!";
 }
@@ -263,7 +277,7 @@ sub resolve_xref
   my $self = shift;;
   my ($x) = @_;
   my $xref;
-  $xref = $self->{xrefs}{$x =~ /^\@(.*)\@$/ ? $1 : $x} if defined $x;
+  $xref = $self->{xrefs}{$x =~ /^\@(.+)\@$/ ? $1 : $x} if defined $x;
   $xref;
 }
 
@@ -479,7 +493,7 @@ __END__
 
 Gedcom - a module to manipulate Gedcom genealogy files
 
-Version 1.07 - 14th March 2000
+Version 1.08 - 8th May 2000
 
 =head1 SYNOPSIS
 
@@ -523,6 +537,16 @@ is only usable if you can access a PC running Windows of some
 description.  Part of the reason I wrote this module is because I don't
 do that.  Well, I didn't.  I can now although I prefer not to...
 
+Requirements:
+  Perl 5.005 or later
+  ActivePerl5 Build Number 520 or later has been reported to work
+
+Optional Modules:
+  Date::Manip.pm       to work with dates
+  Text::Soundex.pm     to use soundex
+  Parse::RecDescent.pm to use lines2perl
+  Roman.pm             to use the LifeLines function roman from lines2perl
+
 The Gedcom format is specified in a grammar file (gedcom-5.5.grammar).
 Gedcom.pm parses the grammar which is then used to validate and allow
 manipulation of the Gedcom file.  I have only used Gedcom.pm with
@@ -714,6 +738,7 @@ See Gedcom::Record.pm for more details.
 
   my $ged = Gedcom->new(grammar_version => 5.5,
                         gedcom_file     => $gedcom_file,
+                        read_only       => 1,
                         callback        => $cb);
 
   my $ged = Gedcom->new(grammar_file => "gedcom-5.5.grammar",
@@ -730,6 +755,23 @@ grammar file as grammar_file.  Usually, you will do neither of these,
 and in this case the grammar version will default to the latest
 available version, currently 5.5.
 
+The read_only parameter indicates that the Gedcom data structure will be
+used primarily for read_only operations.  In this mode the gedcom file
+is read lazily, such that whenever possible the Gedcom records are not
+read until they are needed.  This can save on both memory and CPU usage,
+provided that not too much of the gedcom file is needed.  If the whole
+of the gedcom file needs to be read, for example to validate it, or to
+write it out in a different format, then this option should not be used.
+
+With or without the read_only option, the gedcom file is accessed in the
+same fashion and the data structures can be changed.  In this respect,
+the name read_only is not very accurate, but since changing the Gedcom
+data will generally mean that the data will be written which means that
+the data will first be read, the read_only option is generally useful
+when the data will not be written and when not all the data will be
+read.  You may find it useful to experiment with this option and check
+the amount of CPU time and memroy that your application uses.
+
 callback is an optional reference to a subroutine which will be called
 at various times while the gedcom file (and the grammar file, ir
 applicable) is being read.  It's purpose is to provide feedback during
